@@ -16,6 +16,10 @@ class AuthAppMixin:
 
         super().on_begin_request()
 
+    def on_end_response(self):
+        super().on_end_response()
+        self.identity = None
+
     def setup(self):
         super().setup()
         if "auth" in self.config:
